-- -------------------------------------------------------------------------- --
-- GridStatusMTs by kunda                                                     --
-- Please make sure to save this file as UTF-8. ¶                             --
-- -------------------------------------------------------------------------- --

-- Localization START ----------------------------------------------------------
local L = GetLocale()
local LOC_MTs = "MTs"
if L == "deDE" then
	LOC_MTs = "MTs"
elseif L == "koKR" then
	LOC_MTs = "메인 탱커"
elseif L == "ruRU" then
	LOC_MTs = "ГТ"
elseif L == "zhCN" then
	LOC_MTs = "MT"
elseif L == "zhTW" then
	LOC_MTs = "主坦克"
end
-- Localization END ------------------------------------------------------------

local GridRoster = Grid:GetModule("GridRoster")
local GridStatusMTs = Grid:GetModule("GridStatus"):NewModule("GridStatusMTs")
GridStatusMTs.menuName = LOC_MTs

GridStatusMTs.defaultDB = {
	debug = false,
	alert_mt = {
		text = LOC_MTs,
		enable = true,
		color = { r = 1, g = 1, b = 1, a = 0.4 },
		priority = 60,
		range = false,
	}
}

GridStatusMTs.options = false

function GridStatusMTs:OnInitialize()
	self.super.OnInitialize(self)
	self:RegisterStatus("alert_mt", LOC_MTs, nil, true)
end

function GridStatusMTs:OnStatusEnable(status)
	if status == "alert_mt" then
		self:RegisterEvent("oRA_MainTankUpdate", "UpdateMainTankTable")
		self:RegisterEvent("RAID_ROSTER_UPDATE", "UpdateMainTankTable")
		if CT_RAOptions_UpdateMTs then
			hooksecurefunc("CT_RAOptions_UpdateMTs", GridStatusMTs.UpdateMainTankTable)
		end
		self:UpdateMainTankTable()
	end
end

function GridStatusMTs:OnStatusDisable(status)
	if status == "alert_mt" then
		self:UnregisterEvent("oRA_MainTankUpdate", "UpdateMainTankTable")
		self:UnregisterEvent("RAID_ROSTER_UPDATE", "UpdateMainTankTable")
		self.core:SendStatusLostAllUnits("alert_mt")
	end
end

function GridStatusMTs:UpdateMainTankTable()
	self.core:SendStatusLostAllUnits("alert_mt")

	local settings = self.db.profile.alert_mt
	if not settings.enable then return end

	local raid = GetNumRaidMembers()
	if raid <= 1 then return end

	local maintanktable
	local isBlizzMTs -- nil/false = ADDON | true = BLIZZARD

	-- CT_RA START
	if CT_RA_MainTanks then
		maintanktable = CT_RA_MainTanks
	end
	-- CT_RA END

	-- oRA2 START
	if oRA and oRA.maintanktable then
		maintanktable = oRA.maintanktable
	end
	-- oRA2 END

	-- oRA3 START
	if oRA3 and oRA3.GetSortedTanks then
		maintanktable = oRA3:GetSortedTanks()
	end
	-- oRA3 END

	local check
	local MTtotal = 0
	if maintanktable then
		for i = 1, 10 do
			if maintanktable[i] and maintanktable[i] ~= "" then
				MTtotal = MTtotal + 1
				check = true
			end
		end
	end

	if not check then
		maintanktable = nil
	end

	-- Blizzard START
	if not maintanktable then
		maintanktable = {}
		local x = 1
		if raid > 0 then
			for i = 1, raid do
				local name, _, _, _, _, _, _, _, _, role = GetRaidRosterInfo(i)
				if name and role and role == "MAINTANK" then
					maintanktable[x] = name
					x = x + 1
					if x > 10 then
						break
					end
				end
			end
		end
		if maintanktable[1] then
			isBlizzMTs = true
		else
			maintanktable = nil
		end
	end
	-- Blizzard END

	if not maintanktable then return end

	-- update status START
	local MTicon = "Interface\\AddOns\\GridStatusMTs\\icons\\mt.tga"
	local MTtext = "MT"
	local MTcount = 0

	for guid in GridRoster:IterateRoster() do
		local name = GridRoster:GetNameByGUID(guid)

		for i = 1, 10 do
			if maintanktable[i] and maintanktable[i] == name then
				if not isBlizzMTs then
					MTicon = "Interface\\AddOns\\GridStatusMTs\\icons\\mt"..i..".tga"
					MTtext = "MT"..i
				end
				self.core:SendStatusGained(guid, "alert_mt",
					settings.priority,
					(settings.range and 40),
					settings.color,
					MTtext,
					nil,
					nil,
					MTicon)
				MTcount = MTcount + 1
			end
		end

		if MTcount == MTtotal then
			break
		end

	end
	-- update status END
end